@@ -1523,8 +1523,6 @@ vteapp_window_show_context_menu(VteappWindow* window,
                         else
                                 verbose_print("%s match: %s\n", extra_pattern, extra_match);
                 }
-                g_free(hyperlink);
-                g_free(match);
                 g_free(extra_match);
                 g_free(extra_subst);
         }
@@ -2184,9 +2182,7 @@ main(int argc,
         setlocale(LC_ALL, "");
 
 	bindtextdomain(GETTEXT_PACKAGE, LOCALEDIR);
-#ifdef HAVE_DECL_BIND_TEXTDOMAIN_CODESET
 	bind_textdomain_codeset(GETTEXT_PACKAGE, "UTF-8");
-#endif
 
         /* Not interested in silly debug spew, bug #749195 */
         if (g_getenv("G_ENABLE_DIAGNOSTIC") == nullptr)
