@@ -76,6 +76,8 @@
 
 #define VTE_VERSION_NUMERIC ((VTE_MAJOR_VERSION) * 10000 + (VTE_MINOR_VERSION) * 100 + (VTE_MICRO_VERSION))
 
+#define VTE_TERMINFO_NAME "xterm-256color"
+
 #if !GLIB_CHECK_VERSION(2, 42, 0)
 #define G_PARAM_EXPLICIT_NOTIFY 0
 #endif
@@ -229,7 +231,7 @@ vte_pty_child_setup (VtePty *pty)
         /* Now set the TERM environment variable */
         /* FIXME: Setting environment here seems to have no effect, the merged envp2 will override on exec.
          * By the way, we'd need to set the one from there, if any. */
-        g_setenv("TERM", VTE_DEFAULT_TERM, TRUE);
+        g_setenv("TERM", VTE_TERMINFO_NAME, TRUE);
 
         char version[7];
         g_snprintf (version, sizeof (version), "%u", VTE_VERSION_NUMERIC);
@@ -256,6 +258,7 @@ vte_pty_child_setup (VtePty *pty)
  */
 static gchar **
 __vte_pty_merge_environ (char **envp,
+                         const char *directory,
                          gboolean inherit)
 {
 	GHashTable *table;
@@ -278,7 +281,7 @@ __vte_pty_merge_environ (char **envp,
 	}
 
         /* Make sure the one in envp overrides the default. */
-        g_hash_table_replace (table, g_strdup ("TERM"), g_strdup (VTE_DEFAULT_TERM));
+        g_hash_table_replace (table, g_strdup ("TERM"), g_strdup (VTE_TERMINFO_NAME));
 
 	if (envp != NULL) {
 		for (i = 0; envp[i] != NULL; i++) {
@@ -297,6 +300,13 @@ __vte_pty_merge_environ (char **envp,
 	/* Always set this ourself, not allowing replacing from envp */
 	g_hash_table_replace(table, g_strdup("COLORTERM"), g_strdup("truecolor"));
 
+        /* We need to put the working directory also in PWD, so that
+         * e.g. bash starts in the right directory if @directory is a symlink.
+         * See bug #502146 and #758452.
+         */
+        if (directory)
+                g_hash_table_replace(table, g_strdup("PWD"), g_strdup(directory));
+
 	array = g_ptr_array_sized_new (g_hash_table_size (table) + 1);
         g_hash_table_iter_init(&iter, table);
         while (g_hash_table_iter_next(&iter, (void**) &name, (void**) &value)) {
@@ -384,7 +394,7 @@ __vte_pty_spawn (VtePty *pty,
         spawn_flags &= ~VTE_SPAWN_NO_PARENT_ENVV;
 
         /* add the given environment to the childs */
-        envp2 = __vte_pty_merge_environ (envv, inherit_envv);
+        envp2 = __vte_pty_merge_environ (envv, directory, inherit_envv);
 
         _VTE_DEBUG_IF (VTE_DEBUG_MISC) {
                 g_printerr ("Spawning command:\n");
@@ -978,7 +988,7 @@ vte_pty_new_sync (VtePtyFlags flags,
 
 /**
  * vte_pty_new_foreign_sync: (constructor)
- * @fd: (transfer full): a file descriptor to the PTY
+ * @fd: a file descriptor to the PTY
  * @cancellable: (allow-none): a #GCancellable, or %NULL
  * @error: (allow-none): return location for a #GError, or %NULL
  *
@@ -1009,8 +1019,9 @@ vte_pty_new_foreign_sync (int fd,
  * vte_pty_get_fd:
  * @pty: a #VtePty
  *
- * Returns: (transfer none): the file descriptor of the PTY master in @pty. The
- *   file descriptor belongs to @pty and must not be closed
+ * Returns: the file descriptor of the PTY master in @pty. The
+ *   file descriptor belongs to @pty and must not be closed of have
+ *   its flags changed
  */
 int
 vte_pty_get_fd (VtePty *pty)
