@@ -25,7 +25,7 @@
 #include <gtk/gtk.h>
 #include <atk/atk.h>
 #ifdef USE_VTE
-#include "vte.h"
+#include <vte/vte.h>
 #endif
 
 static GArray *contents = NULL;
@@ -89,10 +89,10 @@ terminal_shell_vte(GtkWidget *terminal)
 static void
 update_contents(AtkObject *obj, GtkWidget *widget)
 {
-	int caret, i;
+	guint caret, i;
 	GString *s;
 
-	caret = atk_text_get_caret_offset(ATK_TEXT(obj));
+	caret = (guint)atk_text_get_caret_offset(ATK_TEXT(obj));
 	s = g_string_new(NULL);
 	for (i = 0; i < contents->len; i++) {
 		if (i == caret) {
@@ -142,7 +142,7 @@ text_changed_insert(AtkObject *obj, gint offset, gint length, gpointer data)
 	i = 0;
 	while (i < length) {
 		c = g_utf8_get_char(p);
-		if (offset + i >= contents->len) {
+		if ((guint)(offset + i) >= contents->len) {
 			g_array_append_val(contents, c);
 		} else {
 			g_array_insert_val(contents, offset + i, c);
@@ -172,7 +172,7 @@ text_changed_delete(AtkObject *obj, gint offset, gint length, gpointer data)
 {
 	int i;
 	for (i = offset + length - 1; i >= offset; i--) {
-		if (i > contents->len - 1) {
+		if ((guint)i > contents->len - 1) {
 			g_warning("Invalid character %d was deleted.\n", i);
 		}
 		g_array_remove_index(contents, i);
@@ -241,11 +241,11 @@ terminal_adjustment(GtkWidget *terminal)
 int
 main(int argc, char **argv)
 {
-	GtkWidget *label, *terminal, *tophalf, *pane, *window, *scrollbar, *sw;
+	GtkWidget *label, *terminal, *tophalf, *pane, *window, *sw;
 	AtkObject *obj;
 	char *text, *p;
 	gunichar c;
-	gint count;
+	guint count;
 
 	gtk_init(&argc, &argv);
 
@@ -258,7 +258,6 @@ main(int argc, char **argv)
 	gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(tophalf),
 				       GTK_POLICY_AUTOMATIC,
 				       GTK_POLICY_AUTOMATIC);
-	scrollbar = NULL;
 	gtk_container_add(GTK_CONTAINER(tophalf), terminal);
 #else
 	tophalf = gtk_hbox_new(FALSE, 0);
@@ -266,7 +265,7 @@ main(int argc, char **argv)
 	gtk_box_pack_start(GTK_BOX(tophalf), terminal, TRUE, TRUE, 0);
 	gtk_widget_show(terminal);
 
-	scrollbar = gtk_vscrollbar_new(terminal_adjustment(terminal));
+	GtkWidget* scrollbar = gtk_vscrollbar_new(terminal_adjustment(terminal));
 	gtk_box_pack_start(GTK_BOX(tophalf), scrollbar, FALSE, TRUE, 0);
 	gtk_widget_show(scrollbar);
 #endif
@@ -303,7 +302,7 @@ main(int argc, char **argv)
 	g_signal_connect(G_OBJECT(obj), "text-selection-changed",
 			 G_CALLBACK(text_selection_changed), label);
 
-	count = atk_text_get_character_count(ATK_TEXT(obj));
+	count = (guint)atk_text_get_character_count(ATK_TEXT(obj));
 	if (count > 0) {
 		text = atk_text_get_text(ATK_TEXT(obj), 0, count);
 		if (text != NULL) {
