@@ -1067,6 +1067,9 @@ Ring::frozen_row_text_offset_to_column(row_t position,
 	} else
 		records[1].text_start_offset = _vte_stream_head (m_text_stream);
 
+	g_assert_cmpuint(offset->text_offset, >=, records[0].text_start_offset);
+	g_assert_cmpuint(offset->text_offset, <, records[1].text_start_offset);
+
 	g_string_set_size (buffer, records[1].text_start_offset - records[0].text_start_offset);
 	if (!_vte_stream_read(m_text_stream, records[0].text_start_offset, buffer->str, buffer->len))
 		return false;
@@ -1074,13 +1077,6 @@ Ring::frozen_row_text_offset_to_column(row_t position,
 	if (G_LIKELY (buffer->len && buffer->str[buffer->len - 1] == '\n'))
 		buffer->len--;
 
-        /* Now that we've chopped off the likely trailing newline (which is only rarely missing,
-         * if the ring ends in a soft wrapped line; see bug 181), the position we're about to
-         * locate can be anywhere in the string, including just after its last character,
-         * but not beyond that. */
-        g_assert_cmpuint(offset->text_offset, >=, records[0].text_start_offset);
-        g_assert_cmpuint(offset->text_offset, <=, records[0].text_start_offset + buffer->len);
-
 	row = index(position);
 
 	/* row and buffer now contain the same text, in different representation */
@@ -1088,7 +1084,7 @@ Ring::frozen_row_text_offset_to_column(row_t position,
 	/* count the number of characters for the given UTF-8 text offset */
 	off = offset->text_offset - records[0].text_start_offset;
 	num_chars = 0;
-	for (i = 0; i < off; i++) {
+	for (i = 0; i < off && i < buffer->len; i++) {
 		if ((buffer->str[i] & 0xC0) != 0x80) num_chars++;
 	}
 
@@ -1186,15 +1182,14 @@ Ring::rewrap(column_t columns,
 		/* Find the boundaries of the next paragraph */
 		gboolean prev_record_was_soft_wrapped = FALSE;
 		gboolean paragraph_is_ascii = TRUE;
-		gsize paragraph_start_row = old_row_index - 1;
-		gsize paragraph_end_row;  /* points to beyond the end */
 		gsize text_offset = paragraph_start_text_offset;
 		RowRecord new_record;
 		column_t col = 0;
 
 		_vte_debug_print(VTE_DEBUG_RING,
-				"  Old paragraph:  row %" G_GSIZE_FORMAT "  (text_offset %" G_GSIZE_FORMAT ")  up to (exclusive)  ",  /* no '\n' */
-				paragraph_start_row, paragraph_start_text_offset);
+				"  Old paragraph:  row %lu  (text_offset %" G_GSIZE_FORMAT ")  up to (exclusive)  ",  /* no '\n' */
+                                 old_row_index - 1,
+                                 paragraph_start_text_offset);
 		while (old_row_index <= m_end) {
 			prev_record_was_soft_wrapped = old_record.soft_wrapped;
 			paragraph_is_ascii = paragraph_is_ascii && old_record.is_ascii;
@@ -1209,13 +1204,14 @@ Ring::rewrap(column_t columns,
 			if (!prev_record_was_soft_wrapped)
 				break;
 		}
-		paragraph_end_row = old_row_index - 1;
+
 		paragraph_len = paragraph_end_text_offset - paragraph_start_text_offset;
 		if (!prev_record_was_soft_wrapped)  /* The last paragraph can be soft wrapped! */
 			paragraph_len--;  /* Strip trailing '\n' */
 		_vte_debug_print(VTE_DEBUG_RING,
-				"row %" G_GSIZE_FORMAT "  (text_offset %" G_GSIZE_FORMAT ")%s  len %" G_GSIZE_FORMAT "  is_ascii %d\n",
-				paragraph_end_row, paragraph_end_text_offset,
+				"row %lu  (text_offset %" G_GSIZE_FORMAT ")%s  len %" G_GSIZE_FORMAT "  is_ascii %d\n",
+                                 old_row_index - 1,
+                                 paragraph_end_text_offset,
 				prev_record_was_soft_wrapped ? "  soft_wrapped" : "",
 				paragraph_len, paragraph_is_ascii);
 
